@@ -7,7 +7,7 @@ from configparser import ConfigParser
 config = ConfigParser()
 config.read('config.ini')
 
-user_dbname = config["bot"]["bot_name"] + "_user"
+dbname = config["bot"]["bot_name"]
 class User(mongoengine.Document):
     user_id = mongoengine.StringField(required=True)
     first_name = mongoengine.StringField(required=True, max_length=50)
@@ -15,9 +15,8 @@ class User(mongoengine.Document):
     username = mongoengine.StringField(max_length=50)
     language_code = mongoengine.StringField(max_length=10)
     entry_time = mongoengine.DateTimeField(default=datetime.datetime.utcnow)
-    meta = {'db_alias': user_dbname}
+    meta = {'db_alias': dbname}
 
-interaction_dbname = config["bot"]["bot_name"] + "_interaction"
 class Interaction(mongoengine.Document):
     user = mongoengine.ReferenceField(User)
     state=mongoengine.StringField(max_length=50)
@@ -30,5 +29,5 @@ class Interaction(mongoengine.Document):
     interaction_data = mongoengine.StringField(max_length=MAX_MESSAGE_LENGTH)
     interaction_id = mongoengine.IntField()
     date = mongoengine.DateTimeField(default=datetime.datetime.utcnow)
-    meta = {'db_alias': interaction_dbname}
+    meta = {'db_alias': dbname}
 
