@@ -58,7 +58,7 @@ def readActions(format_inhalt_list, messanger="Telegram", asset_url=""):
                 mp3_filepath = os.path.join("assets/", match.group('file'))
                 ogg_filename = match.group('file').replace(".mp3", ".ogg")
                 ogg_filepath =  os.path.join("assets/", ogg_filename)
-                subprocess.run(["ffmpeg", '-i', mp3_filepath, "-b:a", " 64k", "-ac", "1", '-acodec', 'libopus', ogg_filepath, '-y'])
+                subprocess.run(["ffmpeg", "-loglevel", "error", '-i', mp3_filepath, "-b:a", " 64k", "-ac", "1", '-acodec', 'libopus', '-y', "-hide_banner", ogg_filepath])
 
                 if messanger=="Telegram":
                     action["file"] = ogg_filepath
@@ -73,10 +73,13 @@ def readActions(format_inhalt_list, messanger="Telegram", asset_url=""):
             file_match = re.search(r"Datei: (?P<file>.*)", inhalt)
 
             if file_match:
-                action["url"] = os.path.join(asset_url, file_match.group('file'))
-                if requests.get(action["url"]).status_code != 200:
-                    print("Die angegebene Datei ({}) konnte nicht unter der Asset URL ({}) gefunden werden.".format(
-                    file_match.group('file'), asset_url))
+                if messanger=="Telegram":
+                    action["file"] = file_match.group('file')
+                else:
+                    action["url"] = os.path.join(asset_url, file_match.group('file'))
+                    if requests.get(action["url"]).status_code != 200:
+                        print("Die angegebene Datei ({}) konnte nicht unter der Asset URL ({}) gefunden werden.".format(
+                        file_match.group('file'), asset_url))
             else:
                 action["url"] = os.path.join(asset_url, "platzhalter.png")
 
