@@ -92,14 +92,23 @@ class Interaktion:
                         + readActions([("Return", "{}_AUFLOESUNG".format(poi_name.upper()))], messanger=messanger, asset_url=asset_url)
 
                 elif aktion.startswith("trigger_"):
-                    states["{}_FRAGE".format(poi_name.upper())] += readTriggers(
-                        aktion_list, "{}_{}".format(poi_name, aktion.replace("trigger_", "antwort_")))
+                    if aktion != "trigger_weiter":
+                        states["{}_FRAGE".format(poi_name.upper())] += readTriggers(
+                            aktion_list, "{}_{}".format(poi_name, aktion.replace("trigger_", "antwort_")))
 
             states["{}_FRAGE".format(poi_name.upper())] += readTriggers([("Liste", "Weiter")], "{}_aufloesung".format(poi_name)) \
                 + [{"handler": "TypeHandler", "type": "Update",
                     "action": "{}_tipp".format(poi_name)}]
 
-            states["{}_AUFLOESUNG".format(poi_name.upper())] = readTriggers([("Liste", "Weiter")], next_interaktion) \
+            # Trigger weiter
+            if "trigger_weiter" in interaktion_dict.keys():
+                trigger_weiter = interaktion_dict["trigger_weiter"]
+            else:
+                trigger_weiter = [("Liste", "Weiter")]
+                print(
+                    "Info: {} hat keinen Trigger weiter - der Standardwert wird benutzt.".format(poi_name))
+
+            states["{}_AUFLOESUNG".format(poi_name.upper())] = readTriggers(trigger_weiter, next_interaktion) \
                 + readTriggers([("Liste", "Zurueck")], "{}_frage".format(poi_name)) \
                 + [{"handler": "TypeHandler", "type": "Update", "action": "weiter_tipp"}]
 
@@ -146,7 +155,15 @@ class Interaktion:
                 print("Der Schätzfragentyp {} ist nicht bekannt!".format(
                     interaktion_dict["Typ"][0][0]))
 
-            states["{}_AUFLOESUNG".format(poi_name.upper())] = readTriggers([("Liste", "Weiter")], next_interaktion) \
+            # Trigger weiter
+            if "trigger_weiter" in interaktion_dict.keys():
+                trigger_weiter = interaktion_dict["trigger_weiter"]
+            else:
+                trigger_weiter = [("Liste", "Weiter")]
+                print(
+                    "Info: {} hat keinen Trigger weiter - der Standardwert wird benutzt.".format(poi_name))
+
+            states["{}_AUFLOESUNG".format(poi_name.upper())] = readTriggers(trigger_weiter, next_interaktion) \
                 + [{"handler": "TypeHandler", "type": "Update", "action": "weiter_tipp"}]
 
         elif interaction_typ == "Listenfrage":
@@ -181,11 +198,12 @@ class Interaktion:
                                                                         + readActions(interaktion_dict["richtig Antwort"], messanger=messanger, asset_url=asset_url)
 
                 elif aktion.startswith("trigger_"):
-                    states["{}_FRAGE".format(poi_name.upper())] += readTriggers(
-                        aktion_list, "{}_{}".format(poi_name, aktion.replace("trigger_", "antwort_")))
+                    if aktion != "trigger_weiter":
+                        states["{}_FRAGE".format(poi_name.upper())] += readTriggers(
+                            aktion_list, "{}_{}".format(poi_name, aktion.replace("trigger_", "antwort_")))
 
-                    states["{}_AUFLOESUNG".format(poi_name.upper())] += readTriggers(
-                        aktion_list, "{}_{}_re".format(poi_name, aktion.replace("trigger_", "antwort_")))
+                        states["{}_AUFLOESUNG".format(poi_name.upper())] += readTriggers(
+                            aktion_list, "{}_{}_re".format(poi_name, aktion.replace("trigger_", "antwort_")))
 
             actions["{}_aufloesung".format(poi_name)] = [{"type": "function", "func": "eval_list", "answer_id_name_list": answer_id_name_list, "poi": poi_name, "response_text": interaktion_dict["response_text"][0][1]}]\
                 + readActions(interaktion_dict["Aufloesung"], messanger=messanger, asset_url=asset_url) \
@@ -198,7 +216,15 @@ class Interaktion:
                 + [{"handler": "TypeHandler", "type": "Update",
                     "action": "{}_falsche_antwort".format(poi_name)}]
 
-            states["{}_AUFLOESUNG".format(poi_name.upper())] += readTriggers([("Liste", "Weiter")], next_interaktion) \
+            # Trigger weiter
+            if "trigger_weiter" in interaktion_dict.keys():
+                trigger_weiter = interaktion_dict["trigger_weiter"]
+            else:
+                trigger_weiter = [("Liste", "Weiter")]
+                print(
+                    "Info: {} hat keinen Trigger weiter - der Standardwert wird benutzt.".format(poi_name))
+
+            states["{}_AUFLOESUNG".format(poi_name.upper())] += readTriggers(trigger_weiter, next_interaktion) \
                 + [{"handler": "TypeHandler", "type": "Update", "action": "weiter_tipp"}]
 
         elif interaction_typ == "Beteiligungsfrage":
@@ -216,7 +242,15 @@ class Interaktion:
                 + [{"handler": "TypeHandler", "type": "Update",
                     "action": "{}_tipp".format(poi_name)}]
 
-            states["{}_AUFLOESUNG".format(poi_name.upper())] = readTriggers([("Liste", "Weiter")], next_interaktion) \
+            # Trigger weiter
+            if "trigger_weiter" in interaktion_dict.keys():
+                trigger_weiter = interaktion_dict["trigger_weiter"]
+            else:
+                trigger_weiter = [("Liste", "Weiter")]
+                print(
+                    "Info: {} hat keinen Trigger weiter - der Standardwert wird benutzt.".format(poi_name))
+
+            states["{}_AUFLOESUNG".format(poi_name.upper())] = readTriggers(trigger_weiter, next_interaktion) \
                 + [{"handler": "TypeHandler", "type": "Update", "action": "weiter_tipp"}]
 
         elif interaction_typ == "GIF Generator":
@@ -229,9 +263,16 @@ class Interaktion:
             actions["{}_aufloesung".format(poi_name)] = readActions(
                 interaktion_dict["Aufloesung"], messanger=messanger, asset_url=asset_url)
 
+            # Trigger weiter
+            if "trigger_weiter" in interaktion_dict.keys():
+                trigger_weiter = interaktion_dict["trigger_weiter"]
+            else:
+                trigger_weiter = [("Liste", "Weiter"), ("Liste", "Nein")]
+                print(
+                    "Info: {} hat keinen Trigger weiter - der Standardwert wird benutzt.".format(poi_name))
+
             states["{}_FRAGE".format(poi_name.upper())] = readTriggers([("Foto", "")], "{}_aufloesung".format(poi_name)) \
-                + readTriggers([("Liste", "Weiter")], next_interaktion) \
-                + readTriggers([("Liste", "Nein")], next_interaktion) \
+                + readTriggers(trigger_weiter, next_interaktion) \
                 + [{"handler": "TypeHandler", "type": "Update",
                     "action": "{}_tipp".format(poi_name)}]
 
@@ -239,7 +280,15 @@ class Interaktion:
             actions["{}_info".format(poi_name)] = readActions(
                 interaktion_dict["Info"] + [("Return", "{}_INFO".format(poi_name.upper()))], messanger=messanger, asset_url=asset_url)
 
-            states["{}_INFO".format(poi_name.upper())] = readTriggers([("Liste", "Weiter")], next_interaktion) \
+            # Trigger weiter
+            if "trigger_weiter" in interaktion_dict.keys():
+                trigger_weiter = interaktion_dict["trigger_weiter"]
+            else:
+                trigger_weiter = [("Liste", "Weiter")]
+                print(
+                    "Info: {} hat keinen Trigger weiter - der Standardwert wird benutzt.".format(poi_name))
+
+            states["{}_INFO".format(poi_name.upper())] = readTriggers(trigger_weiter, next_interaktion) \
                 + [{"handler": "TypeHandler", "type": "Update", "action": "weiter_tipp"}]
 
         elif interaction_typ == "Assoziationskette":
@@ -256,7 +305,15 @@ class Interaktion:
             actions["{}_aufloesung".format(poi_name)] = readActions(
                 interaktion_dict["Aufloesung"] + [("Return", "{}_AUFLOESUNG".format(poi_name.upper()))], messanger=messanger, asset_url=asset_url)
 
-            states["{}_AUFLOESUNG".format(poi_name.upper())] = readTriggers([("Liste", "Weiter")], next_interaktion) \
+            # Trigger weiter
+            if "trigger_weiter" in interaktion_dict.keys():
+                trigger_weiter = interaktion_dict["trigger_weiter"]
+            else:
+                trigger_weiter = [("Liste", "Weiter")]
+                print(
+                    "Info: {} hat keinen Trigger weiter - der Standardwert wird benutzt.".format(poi_name))
+
+            states["{}_AUFLOESUNG".format(poi_name.upper())] = readTriggers(trigger_weiter, next_interaktion) \
                 + [{"handler": "TypeHandler", "type": "Update", "action": "weiter_tipp"}]
 
         else:
